Shared Socketry Rust project conventions and development tasks.
Add this crate to a private bake/ package to link the standard project
tasks and their published agent context into a repository.
Functions
- after_
version_ bump - Refresh the standard project files after a Cargo version bump.
- after_
version_ bump_ task - Generated Bake task descriptor.