Crate socketry_project

Crate socketry_project 

Shared Socketry Rust project conventions and development tasks.

Add this crate to a private bake/ package to link the standard project tasks and their published agent context into a repository.

Functions

after_version_bump
Refresh the standard project files after a Cargo version bump.
after_version_bump_task
Generated Bake task descriptor.